function [v2s_off, v2s_on, fric_locs, new_bin_long] = RMS_find_vowels_and_silence(audiofolname,filename)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% RNS_FIND_VOWELS_AND_SILENCE.M calculates vowel to silence ratios and
% fricative locations from an audiofile. Input files are assumed to have a
% sampling rate of 44100 Hz.
%
% Author: Matti Groll (mgroll@bu.edu)
%         Stepp Lab, Boston University, MA
% Date:   3/25/2020
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

global maxpkn

%Load data
[raw_data, fs] = audioread([audiofolname filename]);

%Set parameters
win_len = 300;
step = 10;
ifi_num = maxpkn;


% Filter out heavy background noise, focus on frequencies where vowel formants are present
[B, A] = butter(5,[100/(fs/2) 1000/(fs/2)]);
data = filtfilt(B,A,raw_data);

ind = 1;

rms_vec = [];

%calculate rms based on window length and step size
while ind <= length(data)
    if ind + win_len <= length(data)
        rms_vec = [rms_vec sqrt(mean(data(ind:ind+win_len).^2))];
    else
        rms_vec = [rms_vec sqrt(mean(data(ind:end).^2))];
    end
    ind = ind + step; 
end

%Take log of rms and smooth to make the boundaries easier to identify
rms_vec = log(rms_vec./max(abs(rms_vec)));
rms_vec = movmean(rms_vec,500);




bin_num = 3;

rms_disc = discretize(rms_vec,bin_num);
binary = (rms_disc == bin_num)';
binary(1) = 0; binary(end) = 0;
   
%% Remove Little Peaks %%%%%%%%%%%%%%%%%%%%%% MAKE A FUNCTION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if ~isempty(find(diff(find(abs(diff(binary)) == 1)) < 90));
    vec1 = []; vec2 = []; nums = [];
    vec2 = find(diff(find(abs(diff(binary)) == 1)) < 90);
    vec1 = find(abs(diff(binary)) == 1);
    nums = sort(vec1([vec2; vec2+1])); nums = reshape(nums,numel(nums),1);
    for i = 1:length(nums)/2
        binary(nums((i*2)-1):nums(i*2)) = 0;
        rms_disc(nums((i*2)-1):nums(i*2)) = rms_disc(nums(i*2)+1);
    end
end

%% Add new ONs from discretized function if not enough ONs detected
if length(find(diff(binary) == 1)) < ifi_num*2
    vec1 = []; nums = [];
    nums = find(abs(diff(rms_disc)) == 1);
    for i = 1:length(nums)-1
        if rms_disc(nums(i)) == 1 & rms_disc(nums(i)+1) == 2 & rms_disc(nums(i+1)+1) == 1 
            vec1(i) = true(1);
        else
            vec1(i) = false(1);
        end
    end
    nums = sort(nums([find(vec1) find(vec1)+1])); nums = reshape(nums,numel(nums),1);
    for i = 1:length(nums)/2
        binary(nums((i*2)-1):nums(i*2)) = 1;
    end
end

%% Redo for bin_num + 1 if not enough ONs detected
if length(find(diff(binary) == 1)) < ifi_num*2
    bin_num = bin_num + 1;
    rms_disc = discretize(rms_vec,bin_num);
    binary = (rms_disc == bin_num)';
    binary(1) = 0; binary(end) = 0;
    
    %Remove Little Peaks
    if ~isempty(find(diff(find(abs(diff(binary)) == 1)) < 90));
        vec2 = find(diff(find(abs(diff(binary)) == 1)) < 90);
        vec1 = find(abs(diff(binary)) == 1);
        nums = sort(vec1([vec2; vec2+1])); nums = reshape(nums,numel(nums),1);
        for i = 1:length(nums)/2
            binary(nums((i*2)-1):nums(i*2)) = 0;
            rms_disc(nums((i*2)-1):nums(i*2)) = rms_disc(nums(i*2)+1);
        end
    end
    
    %Add new ONs from discretized function if not enough ONs detected
    if length(find(diff(binary) == 1)) < ifi_num*2
        vec1 = []; nums = [];
        nums = find(abs(diff(rms_disc)) == 1);
        for i = 1:length(nums)-1
            if rms_disc(nums(i)) == 2 & rms_disc(nums(i)+1) == 3 & rms_disc(nums(i+1)+1) == 2 
                vec1(i) = true(1);
            elseif rms_disc(nums(i)) == 1 & rms_disc(nums(i)+1) == 2 & rms_disc(nums(i+1)+1) == 1
                vec1(i) = true(1);
            else
                vec1(i) = false(1);
            end
        end
        nums = sort(nums([find(vec1); find(vec1)+1])); nums = reshape(nums,numel(nums),1);
        for i = 1:length(nums)/2
            binary(nums((i*2)-1):nums(i*2)) = 1;
        end
    end
end


%% Redo for bin_num + 2
if length(find(diff(binary) == 1)) < ifi_num*2
    bin_num = bin_num + 1;
    rms_disc = discretize(rms_vec,bin_num);
    binary = (rms_disc == bin_num)';
    binary(1) = 0; binary(end) = 0;
    
    %Remove Little Peaks
    if ~isempty(find(diff(find(abs(diff(binary)) == 1)) < 90));
        vec2 = find(diff(find(abs(diff(binary)) == 1)) < 90);
        vec1 = find(abs(diff(binary)) == 1);
        nums = sort(vec1([vec2; vec2+1])); nums = reshape(nums,numel(nums),1);
        for i = 1:length(nums)/2
            binary(nums((i*2)-1):nums(i*2)) = 0;
            rms_disc(nums((i*2)-1):nums(i*2)) = rms_disc(nums(i*2)+1);
        end
    end
    
    %Add new ONs from discretized function if not enough ONs detected
    if length(find(diff(binary) == 1)) < ifi_num*2
        vec1 = []; nums = [];
        nums = find(abs(diff(rms_disc)) == 1);
        for i = 1:length(nums)-1
            if rms_disc(nums(i)) == 3 & rms_disc(nums(i)+1) == 4 & rms_disc(nums(i+1)+1) == 3 
                vec1(i) = true(1);
            elseif rms_disc(nums(i)) == 2 & rms_disc(nums(i)+1) == 3 & rms_disc(nums(i+1)+1) == 2 
                vec1(i) = true(1);
            elseif rms_disc(nums(i)) == 1 & rms_disc(nums(i)+1) == 2 & rms_disc(nums(i+1)+1) == 1
                vec1(i) = true(1);
            else
                vec1(i) = false(1);
            end
        end
        nums = sort(nums([find(vec1); find(vec1)+1])); nums = reshape(nums,numel(nums),1);
        for i = 1:length(nums)/2
            binary(nums((i*2)-1):nums(i*2)) = 1;
        end
    end
end

%% Give Up if not enough ONs detected
if length(find(diff(binary) == 1)) < ifi_num*2
    fprintf('Cannot identify fricative location; skipping file')
    v2s_off = [];
    v2s_on = []; 
    fric_locs = [];
    new_bin_long = [];
    figure
    hold on
    plot(binary)
    plot(rms_vec)
    plot(rms_disc)
    return
end


%% Final Edits
diff_bin = diff(binary);
diff_bin_locs = find(abs(diff_bin) == 1);


%Find largest sections
on_lens = [];
for i = 1:(length(diff_bin_locs)/2)
    on_lens(i) = diff_bin_locs(2*i) - diff_bin_locs((2*i)-1);
end
topx = maxk(on_lens,2*ifi_num);
kill_ind = find(~ismember(on_lens,topx));

kill_ind = reshape([((kill_ind.*2)-1)' (kill_ind.*2)'].',1,length(kill_ind)*2);
diff_bin_locs(kill_ind) = [];


new_bin = zeros(length(binary),1);
for i = 1:length(diff_bin_locs)/2
    
    new_bin(diff_bin_locs((2*i)-1)+1:diff_bin_locs(2*i)) = 1;
    
end

new_bin_long = interp(new_bin,10);
new_bin_long = new_bin_long(1:length(raw_data));
new_bin_long = new_bin_long >= .5;

locs = find(abs(diff(new_bin_long)) == 1);

vowels = raw_data(new_bin_long == 1);
for i = 1:ifi_num
    v_rms_off(i) = sqrt(mean(raw_data(locs((4*i)-3):locs((4*i)-2)).^2));
    v_rms_on(i) = sqrt(mean(raw_data(locs((4*i)-1):locs((4*i))).^2));
    fric_locs(i) = round(mean(locs(((4*i)-2):((4*i)-1))));
end

silence = [];
for i = 1:floor(4*ifi_num/5)
    str = locs(4*i); stp = locs((4*i)+1);
    str = str + floor((stp - str)/3);
    stp = stp - floor((stp - str)/3);
    silence = [silence; raw_data(str:stp)];
end
silence_rms = sqrt(mean(silence.^2));
v2s_off = (v_rms_off - silence_rms)./(silence_rms);
v2s_on = (v_rms_on - silence_rms)./(silence_rms);


%% Plot
figure
hold on
plot(rms_vec)
plot(new_bin)
title(filename)

figure
hold on
plot(raw_data./max(abs(raw_data)))
plot(new_bin_long)
plot(fric_locs,zeros(length(fric_locs),1),'*')
title(filename)


